# Copyright 2013 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""maas-test utilities."""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

__metaclass__ = type
__all__ = [
    "read_file",
    "run_command",
    ]

from pipes import quote
from subprocess import (
    PIPE,
    Popen,
    )


def read_file(path):
    """Return a given file's contents, as `bytes`."""
    with open(path) as f:
        return f.read()


def run_command(args, input=None, check_call=False):
    """A wrapper to Popen to run commands in the command-line."""
    process = Popen(args, stdout=PIPE, stderr=PIPE, stdin=PIPE, shell=False)
    stdout, stderr = process.communicate(input)
    retcode = process.returncode
    if check_call and retcode != 0:
        cmd = " ".join(quote(arg) for arg in args)
        raise Exception(
            "Command '%s' failed (%d):\n%s\n%s" % (
                cmd, retcode, stdout, stderr))
    return retcode, stdout, stderr
